package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Jul 22, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Manifest struct {
SchemaVersion string `json:"schema_version"`
CreatedAt time.Time `json:"created_at"`
Files []string `json:"files"`
SHA256 map[string]string `json:"sha256"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.